@@ -682,7 +682,7 @@ gdm_factory_slave_run (GdmFactorySlave *slave)
                 if (! res) {
                         g_warning (_("Could not start the X "
                                      "server (your graphical environment) "
-                                     "due to some internal error. "
+                                     "due to an internal error. "
                                      "Please contact your system administrator "
                                      "or check your syslog to diagnose. "
                                      "In the meantime this display will be "
