@@ -1062,6 +1062,8 @@ idle_connect_to_display (GdmSimpleSlave *slave)
                         start_greeter (slave);
                         create_new_session (slave);
                 } else {
+                        /* Run the init script. gdmslave suspends until script has terminated */
+                        gdm_slave_run_script (GDM_SLAVE (slave), GDMCONFDIR "/Init", GDM_USERNAME);
                         reset_session (slave);
                 }
         } else {
@@ -1150,7 +1152,7 @@ gdm_simple_slave_run (GdmSimpleSlave *slave)
                 if (! res) {
                         g_warning (_("Could not start the X "
                                      "server (your graphical environment) "
-                                     "due to some internal error. "
+                                     "due to an internal error. "
                                      "Please contact your system administrator "
                                      "or check your syslog to diagnose. "
                                      "In the meantime this display will be "
