@@ -239,8 +239,7 @@ close_welcome_session (GdmWelcomeSession *welcome_session)
 }
 
 static void
-load_lang_config_file (const char  *config_file,
-                       const char **str_array)
+load_lang_config_file (const gchar *config_file, const gchar **str_array)
 {
         gchar         *contents = NULL;
         gchar         *p;
@@ -276,7 +275,7 @@ load_lang_config_file (const char  *config_file,
                 return;
         }
 
-        str_joinv = g_strjoinv ("|", (char **) str_array);
+        str_joinv = g_strjoinv ("|", str_array);
         if (str_joinv == NULL) {
                 g_warning ("Error in joined");
                 g_free (contents);
@@ -356,8 +355,7 @@ get_welcome_environment (GdmWelcomeSession *welcome_session)
         };
         int i;
 
-        load_lang_config_file (LANG_CONFIG_FILE,
-                               (const char **) optional_environment);
+        load_lang_config_file (LANG_CONFIG_FILE, optional_environment);
         env = g_ptr_array_new ();
 
         /* create a hash table of current environment, then update keys has necessary */
@@ -524,7 +522,6 @@ spawn_child_setup (SpawnChildData *data)
 {
         struct passwd *pwent;
         struct group  *grent;
-        int            res;
 
         if (data->user_name == NULL) {
                 return;
@@ -546,11 +543,7 @@ spawn_child_setup (SpawnChildData *data)
 
         g_debug ("GdmWelcomeSession: Setting up run time dir %s", data->runtime_dir);
         g_mkdir (data->runtime_dir, 0755);
-        res = chown (data->runtime_dir, pwent->pw_uid, pwent->pw_gid);
-        if (res == -1) {
-                g_warning ("GdmWelcomeSession: Error setting owner of run time directory: %s",
-                           g_strerror (errno));
-        }
+        chown (data->runtime_dir, pwent->pw_uid, pwent->pw_gid);
 
         g_debug ("GdmWelcomeSession: Changing (uid:gid) for child process to (%d:%d)",
                  pwent->pw_uid,
@@ -774,7 +767,7 @@ parse_dbus_launch_output (const char *output,
         }
 
         if (addressp != NULL) {
-                *addressp = g_match_info_fetch (match_info, 1);
+                *addressp = g_strdup (g_match_info_fetch (match_info, 1));
         }
 
         if (pidp != NULL) {
@@ -811,8 +804,6 @@ start_dbus_daemon (GdmWelcomeSession *welcome_session)
 
         env = get_welcome_environment (welcome_session);
 
-        std_out = NULL;
-        std_err = NULL;
         error = NULL;
         res = spawn_command_line_sync_as_user (DBUS_LAUNCH_COMMAND,
                                                welcome_session->priv->user_name,
@@ -843,8 +834,6 @@ start_dbus_daemon (GdmWelcomeSession *welcome_session)
                 g_debug ("GdmWelcomeSession: Started D-Bus daemon on pid %d", welcome_session->priv->dbus_pid);
         }
  out:
-        g_free (std_out);
-        g_free (std_err);
         return res;
 }
 
@@ -1412,10 +1401,6 @@ gdm_welcome_session_finalize (GObject *object)
 
         gdm_welcome_session_stop (welcome_session);
 
-        if (welcome_session->priv->ckc != NULL) {
-                ck_connector_unref (welcome_session->priv->ckc);
-        }
-
         g_free (welcome_session->priv->command);
         g_free (welcome_session->priv->user_name);
         g_free (welcome_session->priv->group_name);
@@ -1427,8 +1412,6 @@ gdm_welcome_session_finalize (GObject *object)
         g_free (welcome_session->priv->server_address);
         g_free (welcome_session->priv->server_dbus_path);
         g_free (welcome_session->priv->server_dbus_interface);
-        g_free (welcome_session->priv->server_env_var_name);
-        g_free (welcome_session->priv->dbus_bus_address);
 
         G_OBJECT_CLASS (gdm_welcome_session_parent_class)->finalize (object);
 }
